| plot.gg_forest | R Documentation |
gg_forest objects.Uses patchwork to combine the forest plot and table components.
## S3 method for class 'gg_forest'
plot(x, ..., widths = c(1.4, 1))
x |
An object of class |
... |
Other arguments passed to |
widths |
Numeric vector of length 2 giving the relative widths of the table and forest plot components.
The default is |
A ggplot object combining the forest plot and table components.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.