Learn R Programming

VizTest (version 0.7)

plot.gg_forest: Plotting method for gg_forest objects.

Description

Uses patchwork to combine the forest plot and table components.

Usage

# S3 method for gg_forest
plot(x, ..., widths = c(1.4, 1))

Value

A ggplot object combining the forest plot and table components.

Arguments

x

An object of class "gg_foest", produces with the gg_forest() function.

...

Other arguments passed to theme() to control the appearance of the combined plot. For example, you might want to use legend.position = "none" if you don't want a legend for the CI colors.

widths

Numeric vector of length 2 giving the relative widths of the table and forest plot components. The default is c(1.4, 1), which gives the table slightly more width than the forest plot.