gg_forest objects.Uses patchwork to combine the forest plot and table components.
# S3 method for gg_forest
plot(x, ..., widths = c(1.4, 1))A ggplot object combining the forest plot and table components.
An object of class "gg_foest", produces with the gg_forest() function.
Other arguments passed to theme() to control the appearance of the combined plot.
For example, you might want to use legend.position = "none" if you don't want a legend for the CI colors.
Numeric vector of length 2 giving the relative widths of the table and forest plot components.
The default is c(1.4, 1), which gives the table slightly more width than the forest plot.